@@ -3,6 +3,7 @@ import airflow_commons.logger as logger
 from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.mysql.sql_utils import get_delete_sql
 from airflow_commons.utils.mysql.sql_utils import get_select_all_sql
+from airflow_commons.utils.mysql.sql_utils import get_row_count_sql
 
 
 def write_to_mysql(
@@ -111,3 +112,39 @@ def select_all(
     logger.LOGGER("The below sql statement is executed \n" + sql)
     logger.LOGGER("Number of records retrieved = " + str(len(result)))
     return result
+
+
+def get_row_count(
+    username: str,
+    password: str,
+    host: str,
+    db_name: str,
+    table_name: str,
+    where_statement_file: str = None,
+    where_statement_params: dict = None,
+):
+    engine = get_db_engine(username, password, host, db_name)
+    connection = engine.raw_connection()
+
+    if where_statement_file is not None:
+        if where_statement_params is None:
+            where_statement_params = dict()
+        where_statement = read_sql(
+            sql_file=where_statement_file, **where_statement_params
+        )
+    else:
+        where_statement = ""
+
+    sql = get_row_count_sql(
+        table_name=table_name,
+        where_statement=where_statement,
+    )
+
+    logger.LOGGER("The below sql statement will be executed: \n" + sql)
+    cursor = connection.cursor()
+    cursor.execute(sql)
+    row_count = cursor.fetchone()[0]
+    connection.commit()
+    connection.close()
+    logger.LOGGER("The sql statement is executed successfully\n")
+    return row_count
